from django.contrib.auth.decorators import login_required
from django.http import HttpResponse, HttpResponseNotAllowed, HttpResponseBadRequest

from .models import Like


@login_required
def add_or_remove(request):

    if not request.is_ajax():
        return HttpResponseNotAllowed()

    user = request.user

    try:
        app_model = request.POST["target_model"]
        obj_id = int(request.POST["target_object_id"])
    except (KeyError, ValueError):
        return HttpResponseBadRequest()

    like = Like.objects.get_like(user, obj_id, model=app_model)

    if like is None:
        Like.objects.create(user, obj_id, app_model)
        status = 'added'
    else:
        like.delete()
        status = 'deleted'

    likeCount=Like.objects.for_object(obj_id, app_model).count()
    
    return HttpResponse(status+"|"+str(likeCount))




#!/usr/bin/env python

from setuptools import setup, find_packages

README = open('README.md').readlines()

try:
    import pypandoc
    README = pypandoc.convert('README.md', 'rst')
except(IOError, ImportError):
    README = open('README.md').read()

setup(
    name='django-likeit',
    version='0.1.2',
    packages=find_packages(),
    include_package_data=True,
    license='MIT License',
    description=README[2].rstrip('\n'),
    long_description=''.join(README),
    url='https://github.com/malisit/django-likeit',
    download_url='https://github.com/malisit/django-likeit/tarball/0.1',
    author='Muhammed Ali Sit',
    author_email='sitmuhammedali@gmail.com',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        ],
    )
